@@ -1,4 +1,4 @@
 from tests import *
-from ipn import TestPaymentIPN, TestPreapprovalIPN
+from ipn import TestPaymentIPN, TestPreapprovalIPN, TestIPNVerification
 from preapproval_return_url import TestPreapprovalReturnURL
 from payment_return_url import TestPaymentReturnURL
\ No newline at end of file
